@@ -144,13 +144,13 @@ def _(s):
 APP_NAME = "Screenlets"
 
 # the version of the Screenlets-baseclass in use
-VERSION = "0.1.6"
+VERSION = "0.1.7"
 
 # the application copyright
-COPYRIGHT = "(c) RYX (Rico Pfaus) <ryx@ryxperience.com>\nWhise (Helder Fraga) <helder.fraga@hotmail.com>\nNatan Yellin (Aantn) <aantny@gmail.com>\nGuido Tabbernuk <boamaod@gmail.com>"
+COPYRIGHT = "(c) RYX (Rico Pfaus) <ryx@ryxperience.com>\nWhise (Helder Fraga) <helder.fraga@hotmail.com>\nNatan Yellin (Aantn) <aantny@gmail.com>\nGuido Tabbernuk <boamaod@gmail.com> \nRastko Karadzic <rastkokaradzic@gmail.com>"
 
 # the application authors
-AUTHORS = ["RYX (Rico Pfaus) <ryx@ryxperience.com>", "Whise (Helder Fraga) <helder.fraga@hotmail.com>", "Sorcerer (Hendrik Kaju)", "Natan Yellin (Aantn) <aantny@gmail.com>", "Guido Tabbernuk <boamaod@gmail.com>" ]
+AUTHORS = ["RYX (Rico Pfaus) <ryx@ryxperience.com>", "Whise (Helder Fraga) <helder.fraga@hotmail.com>", "Sorcerer (Hendrik Kaju)", "Natan Yellin (Aantn) <aantny@gmail.com>", "Guido Tabbernuk <boamaod@gmail.com>", "Rastko Karadzic <rastkokaradzic@gmail.com>" ]
 
 # the application comments
 COMMENTS = "Screenlets is a widget framework that consists of small owner-drawn applications (written in Python, a very simple object-oriented programming-language) that can be described as 'the virtual representation of things lying/standing around on your desk'. Sticknotes, clocks, rulers, ... the possibilities are endless. Screenlet also tries to include some compatibility with other widget frameworks,like web widgets and super karamba themes"
@@ -400,7 +400,7 @@ class ScreenletTheme (dict):
 			ctx.update_layout(self.p_layout)
 		self.p_fdesc = pango.FontDescription()
 		self.p_fdesc.set_family_static(font)
-		self.p_fdesc.set_size(size * pango.SCALE)
+		self.p_fdesc.set_size(int(round(size * pango.SCALE)))
 		self.p_fdesc.set_weight(weight)
 		self.p_layout.set_font_description(self.p_fdesc)
 		self.p_layout.set_width(width * pango.SCALE)
@@ -719,7 +719,8 @@ class Screenlet (gobject.GObject, EditableOptions, Drawing):
 	__name__	= _('No name set for this Screenlet')
 	__version__	= '0.0'
 	__author__	= _('No author defined for this Screenlet')
-	__desc__	= _('No info set for this Screenlet')
+    	__category__ 	= '10'
+    	__desc__	= _('No info set for this Screenlet')
 	__requires__	= []
 	#__target_version__ = '0.0.0'
 	#__backend_version__ = '0.0.1'
@@ -793,6 +794,9 @@ class Screenlet (gobject.GObject, EditableOptions, Drawing):
 		uses_pango=False, is_sizable=True,resize_on_scroll=True, ask_on_option_override=False):
 		"""Constructor - should only be subclassed"""
 		
+		if DEBIAN and not self.ignore_requirements:
+			self.check_requirements()
+
 		# call gobject and EditableOptions superclasses
 		super(Screenlet, self).__init__()
 		EditableOptions.__init__(self)
@@ -1013,11 +1017,7 @@ class Screenlet (gobject.GObject, EditableOptions, Drawing):
 			
 		if show_window:
 			self.window.show()
-			if self.__name__.endswith("Screenlet"):
-				short_name = self.__name__[:-9]
-			else:
-				short_name = self.__name__
-			if not os.path.exists(DIR_CONFIG + '/' + short_name + '/default/'+ self.id + '.ini'):
+			if not os.path.exists(DIR_CONFIG + '/' + self.get_short_name() + '/default/'+ self.id + '.ini'):
 				self.first_run = True
 			self.window.hide()	
 
@@ -1107,13 +1107,13 @@ class Screenlet (gobject.GObject, EditableOptions, Drawing):
 	
 	def check_requirements (self):
 		'''Checks if required DEB packages are installed'''
-
+		print "check_requirements"
 		req_feedback = ""
 		fail = False
 
 #		operators=['>', '=', '<']
 
-		commandstr = 'LANG=C apt-cache policy %s 2>/dev/null | sed -n "2 p" | grep -v ":[ \t]*([a-z \t]*)" | sed -r -e "s/(\s*[^\s]+:\s*)(.*)/\\2/"'
+		commandstr = 'LANG=C apt-cache policy %s 2>/dev/null | sed -n "2 p" | cut -d : -f 2'
 		for req in self.__requires__:
 			operator = None
 #			req = req.replace(' ', '')
@@ -1134,12 +1134,12 @@ class Screenlet (gobject.GObject, EditableOptions, Drawing):
 				# version of the deb package if unspecified
 				version = _("?")
 
-			installed_version = os.popen(commandstr % package).readline().replace('\n', '')
+			installed_version = os.popen(commandstr % package).readline().replace('\n', '').strip()
 
-			if len(installed_version) < 1:
+			if len(installed_version) < 1 or installed_version == "(none)":
 				req_feedback += _("\n%(package)s %(version)s required, NOT INSTALLED!") % {"package":package, "version":version}
 				fail = True
-			else:
+			else:                                                 	
 				req_feedback += _("\n%(package)s %(version)s installed, req %(required)s.") % {"package":package, "version":installed_version, "required":version}
 				# will fail only if dpkg says that version is too old
 				# otherwise it's responsibility of developer to provide
@@ -1299,8 +1299,8 @@ class Screenlet (gobject.GObject, EditableOptions, Drawing):
 
 
 	def load_buttons(self, event):
-		self.closeb = self.gtk_icon_theme.load_icon ("gtk-close", 16, 0)
-		self.prop = self.gtk_icon_theme.load_icon ("gtk-properties", 16, 0)
+		self.closeb = self.gtk_icon_theme.load_icon ("window-close", 16, 0)
+		self.prop = self.gtk_icon_theme.load_icon ("document-properties", 16, 0)
  
 	def create_buttons(self):
 
@@ -1308,8 +1308,8 @@ class Screenlet (gobject.GObject, EditableOptions, Drawing):
 		ctx.save()
 		#ctx.set_source_rgba(0.5,0.5,0.5,0.6)
 		#self.theme.draw_rounded_rectangle(ctx,(self.width*self.scale)-36,0,5,36,16)
-		#close = theme1.load_icon ("gtk-close", 16, 0)
-		#prop = theme1.load_icon ("gtk-properties", 16, 0)
+		#close = theme1.load_icon ("window-close", 16, 0)
+		#prop = theme1.load_icon ("document-properties", 16, 0)
 		#zoom1 = theme1.load_icon ("gtk-zoom-in", 16, 0)
 		#zoom2 = theme1.load_icon ("gtk-zoom-out", 16, 0)
 		#close = gtk.image_new_from_stock(gtk.STOCK_CLOSE, 16)
@@ -1432,11 +1432,6 @@ class Screenlet (gobject.GObject, EditableOptions, Drawing):
 	def finish_loading(self):
 		"""Called when screenlet finishes loading"""
 		
-
-
-		if DEBIAN and not self.ignore_requirements:
-			self.check_requirements()
-
 		self.window.present()
 		self.show()
 
@@ -1569,8 +1564,8 @@ class Screenlet (gobject.GObject, EditableOptions, Drawing):
 			waited = True
 #			print "WAITING..."
 			time.sleep(1)
-		if waited: # add extra second, since the hack is heuristic
-			time.sleep(1)
+		if waited: # add extra seconds, since the hack is heuristic
+			time.sleep(3)
 		#EOH
 		self.window.move(self.x, self.y)
 		self.window.show()
@@ -1599,6 +1594,7 @@ class Screenlet (gobject.GObject, EditableOptions, Drawing):
 		else:
 			self.update_shape()
 		se.destroy()
+		self.redraw_canvas()
 	
 	def redraw_canvas (self):
 		"""Redraw the entire Screenlet's window area.
@@ -1692,8 +1688,8 @@ class Screenlet (gobject.GObject, EditableOptions, Drawing):
 			#theme1 = gtk.icon_theme_get_default()
 			#ctx.set_source_rgba(0.5,0.5,0.5,0.6)
 			#self.theme.draw_rounded_rectangle(ctx,(self.width*self.scale)-36,0,5,36,16)
-			#close = theme1.load_icon ("gtk-close", 16, 0)
-			#prop = theme1.load_icon ("gtk-properties", 16, 0)
+			#close = theme1.load_icon ("window-close", 16, 0)
+			#prop = theme1.load_icon ("document-properties", 16, 0)
 			#zoom1 = theme1.load_icon ("gtk-zoom-in", 16, 0)
 			#zoom2 = theme1.load_icon ("gtk-zoom-out", 16, 0)
 			#close = gtk.image_new_from_stock(gtk.STOCK_CLOSE, 16)
@@ -1969,11 +1965,9 @@ class Screenlet (gobject.GObject, EditableOptions, Drawing):
 	def composite_changed(self,widget):
 		#this handle is called when composition changed
 		self.remove_shape() # removing previous set shape , this is absolutly necessary
-		self.window.hide() # hiding the window and showing it again so the window can convert to the right composited state
 		self.is_sticky = self.is_sticky	 #changing from non composited to composited makes the screenlets loose sticky state , this fixes that
 		self.keep_above= self.keep_above
 		self.keep_below= self.keep_below
-		self.window.show()
 		#print 'Compositing method changed to %s' % str(self.window.is_composited())
 		self.update_shape()
 		self.redraw_canvas()
