@@ -13,7 +13,7 @@
 
 #  screenlets.utils (c) Whise (Helder Fraga) 2008 <helder.fraga@hotmail.com>
 #  Originaly by RYX (Rico Pfaus) 2007 <ryx@ryxperience.com>
-#
+#  
 # TODO: move more functions here when possible
 #
 
@@ -33,7 +33,7 @@ from distutils.version import LooseVersion
 import subprocess
 import commands
 from HTMLParser import HTMLParser
-from BeautifulSoup import BeautifulStoneSoup
+from bs4 import BeautifulSoup
 from xdg.BaseDirectory import *
 
 try:
@@ -98,7 +98,7 @@ def html_to_pango (html):
 	s = MLStripper()
 	s.feed(html)
 	no_html = s.get_data()
-	decoded = BeautifulStoneSoup(no_html, convertEntities=BeautifulStoneSoup.HTML_ENTITIES)
+	decoded = BeautifulSoup(no_html).get_text()
 	result = decoded.encode("UTF-8")
 	return result.strip(" \n")
 
@@ -168,7 +168,7 @@ def create_autostarter (name):
 		print "Starter already exists."
 		return True
 
-def delete_autostarter ( name):
+def delete_autostarter(name):
 	"""Delete the autostart for the given screenlet."""
 	if name.endswith('Screenlet'):
 		name = name[:-9]
@@ -202,7 +202,7 @@ def get_more_screenlets_ubuntu():
 	if not is_screenlets_ppa_enabled():
 		print "PPA not enabled yet"
 		if screenlets.show_question(None, _('The Screenlets PPA is not listed among Software Sources. Adding this enables installing individual screenlets from Package Manager (or Software Center) and by clicking on an AptURL on web pages like Gnome-look.org. Would you like to add the Screenlets PPA to your system?'), title=_("Do you want to enable the Screenlets PPA?")):
-			result = commands.getstatusoutput('gksudo add-apt-repository ppa:screenlets/ppa && gksudo apt-get update')[0]
+			result = commands.getstatusoutput('gksudo add-apt-repository ppa:screenlets-dev/ppa && gksudo apt-get update')[0]
 			if result == 0:
 				screenlets.show_message(None, _('The Screenlets PPA added successfully.'), title=_("Success!"))
 			else:
@@ -301,6 +301,16 @@ def getBetween(data, first, last):
 	end = data.find(last, begin)
 	return data[begin:end]
 
+def getCatBetween(data, first, last):
+	x = len(first)
+	f=data.find(first)
+	if f==-1:
+		return _('Miscellaneous')
+	else:
+		begin = f +x
+		end = data.find(last, begin)
+		return data[begin:end]
+
 def get_screenlet_metadata_by_path (path):
 	"""Returns a dict with name, info, author and version of the given
 	screenlet. Use with care because it may import the screenlet 
@@ -325,6 +335,10 @@ def get_screenlet_metadata_by_path (path):
 		author = getBetween(sldata,'__author__','\n')
 		author1 = getBetween(author ,"'","'")
 		if author1.find(' = ') != -1: author1 = getBetween(author ,chr(34),chr(34))
+		category = getCatBetween(sldata,'__category__','\n')
+		category1 = getCatBetween(category ,"'","'")
+		if category1.find(' = ') != -1: 
+			category1 = getCatBetween(category ,chr(34),chr(34))
 		version = getBetween(sldata,'__version__','\n')
 		version1 = getBetween(version ,"'","'")
 		if version1.find(' = ') != -1: version1 = getBetween(version ,chr(34),chr(34))
@@ -338,6 +352,7 @@ def get_screenlet_metadata_by_path (path):
 		return {'name'	: name1, 
 			'info'		: gettext.dgettext(get_screenlet_linux_name_by_class_name(name1), info1), 
 			'author'	: author1, 
+			'category'	: category1,
 			'version'	: version1,
 			'requires'	: requires1
 			}		
@@ -352,6 +367,7 @@ def get_screenlet_metadata_by_path (path):
 			return {'name'	: cls.__name__, 
 				'info'		: gettext.dgettext(get_screenlet_linux_name_by_class_name(cls.__name__), cls.__desc__), 
 				'author'	: cls.__author__, 
+				'category'	: cls.__category__,
 				'version'	: cls.__version__,
 				'requires'	: cls.__requires__
 				}
@@ -670,16 +686,17 @@ def xdg_open(name):
 class ScreenletInfo(object):
 	"""A container with info about a screenlet."""
 
-	def __init__ (self, name, lname, info, author, version, icon):
-		self.name		= name
-		self.lname		= lname
-		self.info		= info.replace("\n", '').replace('\t', ' ')
-		self.author		= author
-		self.version	= version
-		self.icon		= icon
-		self.active		= False
-		self.system		= not os.path.isfile('%s/%s/%sScreenlet.py' % (DIR_USER, name, name))
-		self.autostart	= os.path.isfile(DIR_AUTOSTART + '/' + name + 'Screenlet.desktop')
+	def __init__ (self, name, lname, info, author, category,  version, icon):
+		self.name	= name
+		self.lname	= lname
+		self.info	= info.replace("\n", '').replace('\t', ' ')
+		self.author	= author
+        	self.category 	= category
+        	self.version	= version
+        	self.icon	= icon
+       		self.active	= False
+        	self.system	= not os.path.isfile('%s/%s/%sScreenlet.py' % (DIR_USER, name, name))
+        	self.autostart	= os.path.isfile(DIR_AUTOSTART + '/' + name + 'Screenlet.desktop')
 
 
 
