@@ -13,7 +13,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-# Screenlets Manager - (c) RYX (Rico Pfaus) 2007  / Whise (Helder Fraga) <helder.fraga@hotmail.com>
+# Screenlets Manager - (c) RYX (Rico Pfaus) 2007  / Whise (Helder Fraga) <helder.fraga@hotmail.com>, rastkokaradzic (Rastko Karadzic) <rastkokaradzic@gmail.com>
 #
 # + INFO:
 # This is a graphical manager application that simplifies managing and
@@ -21,12 +21,13 @@
 # per-user Screenlets.
 #
 # + TODO:
+# - Implement filter for screenlet-items, appending them every time all over again is too slow
 # - support for using sessions (via commandline), (NOTE: if a session is selected
 #   all autostart-files need to be removed and created new)
 # - Help-button
 # - menu
 #    - different View-modes (icons/details)
-#
+#	
 
 import pygtk
 pygtk.require('2.0')
@@ -66,6 +67,9 @@ else:
 	DIR_USER		= screenlets.DIR_USER
 	DIR_AUTOSTART = utils.get_autostart_dir()
 
+CATEGORIES_ALL = _("All categories")
+CATEGORIES_MISC = _("Miscellaneous")
+
 # classes
 
 
@@ -84,10 +88,22 @@ class ScreenletsManager(object):
 	daemon_iface = None
 	
 	def __init__ (self):
+		#dict of categories that will be shown in combobox
+		self.available_categories = [CATEGORIES_ALL]
+		
 		# create ui and populate it
 		self.create_ui()
 		# populate UI
 		self.load_screenlets()
+		
+		tcats = sorted(self.tmp_cats.items(),key=lambda(k,v):(v,k))[::-1]
+		i = 0
+		while (i<min(10,len(tcats)-1)):
+			self.available_categories.append(_(tcats[i][0]))
+			i=i+1
+		for cat in self.available_categories:
+			self.combo1.append_text(cat)
+		self.combo1.set_active(0)
 		# if we are running as root, show error
 		if USER == 0:
 			screenlets.show_error(None, _("""Important! You are running this application as root user, almost all functionality is disabled. You can use this to install screenlets into the system-wide path."""), 
@@ -99,10 +115,6 @@ class ScreenletsManager(object):
 			self.connect_daemon()	
 		
 	# screenlets stuff
-
-
-	
-
 	
 	def lookup_daemon (self):
 		"""Find the screenlets-daemon or try to launch it. Initializes 
@@ -145,9 +157,9 @@ class ScreenletsManager(object):
 		"""Delete the selected screenlet from the user's screenlet dir."""
 		sel = self.view.get_selected_items()
 		if sel and len(sel) > 0 and len(sel[0]) > 0:
-			it = self.model.get_iter(sel[0][0])
+			it = self.model_filter.get_iter(sel[0][0])
 			if it:
-				info = self.model.get_value(it, 2)
+				info = self.model_filter.get_value(it, 2)
 				if info and not info.system:
 					# delete the file
 					if screenlets.show_question(None, _('Do you really want to permanently uninstall and delete the %sScreenlet from your system?') % info.name, _('Delete Screenlet')):
@@ -161,37 +173,25 @@ class ScreenletsManager(object):
 				else:
 					screenlets.show_error(None, _('Can\'t delete system-wide screenlets.'))
 		return False
-	
+
 	def load_screenlets (self):
 		"""Load all available screenlets, create ScreenletInfo-objects for
-		them and add them to the iconview-model."""
+		them and add them into global dictionary used later for filtering."""
 		# fallback icon
-		noimg = gtk.gdk.pixbuf_new_from_file_at_size(\
+		self.noimg = gtk.gdk.pixbuf_new_from_file_at_size(\
 			screenlets.INSTALL_PREFIX + '/share/screenlets-manager/noimage.svg', 
 			56, 56)
 		# get list of available/running screenlets
+		self.loaded_screenlets = {}
+		self.tmp_cats = {}
 		lst_a = utils.list_available_screenlets()
-		lst_r = utils.list_running_screenlets()
-
-		if not lst_r:
-			lst_r = []
 		lst_a.sort()
-		lst_filtered = []
-		filter_input = str(self.txtsearch.get_text()).lower()
-		combo_sel = self.combo.get_active()
-		if filter_input != '':
-			for s in lst_a:
-				filter_slname = str(s).lower()
-				filter_find = filter_slname.find(filter_input)
-				if filter_input == None or filter_find != -1:
-					lst_filtered.append(s)
-		if lst_filtered == [] and filter_input == '': lst_filtered = lst_a
-		for s in lst_filtered:
+		for s in lst_a:
 			try:
 				img = utils.get_screenlet_icon(s, 56, 56)
 			except Exception, ex:
 				#print "Exception while loading icon '%s': %s" % (path, ex)
-				img = noimg
+				img = self.noimg
 			# get metadata and create ScreenletInfo-object from it
 			meta = utils.get_screenlet_metadata(s)
 			if meta:
@@ -207,38 +207,28 @@ class ScreenletsManager(object):
 				name	= setfield('name', '')
 				info	= setfield('info', '')
 				author	= setfield('author', '')
+				category= setfield('category', CATEGORIES_MISC)
 				version	= setfield('version', '')
+				#Appends category into dict of categories that counts how much screenlets have defined that category.
+				#It's used later to load top defined categories in category filter combobox 
+				if self.tmp_cats.has_key(category):
+					self.tmp_cats[category] += 1
+				else:
+					self.tmp_cats[category] = 1
+
+				
 				# get info
-				slinfo = utils.ScreenletInfo(s, name, info, author, version, img)
-				# check if already running
-				if lst_r.count(s + 'Screenlet'):
-					slinfo.active = True
-				# check if system-wide
-				#if path.startswith(screenlets.INSTALL_PREFIX):
-				#	print "SYSTEM: %s" % s
-				#	info.system = True
+				slinfo = utils.ScreenletInfo(s, name, info, author,category, version, img)
 			else:
 				print 'Error while loading screenlets metadata for "%s".' % s
-				slinfo = utils.ScreenletInfo(s, '', '', '', '', img)
-			# add to model
-
-
-			if combo_sel == 0:
-				self.model.append(['<span size="9000">%s</span>' % s, img, slinfo])	
-			elif combo_sel == 1:
-				if slinfo.active :self.model.append(['<span size="9000">%s</span>' % s, img, slinfo])	
-			elif combo_sel == 2:
-				if slinfo.autostart == True :self.model.append(['<span size="9000">%s</span>' % s, img, slinfo])	
-			elif combo_sel == 3:
-				if slinfo.system == True :self.model.append(['<span size="9000">%s</span>' % s, img, slinfo])	
-			elif combo_sel == 4:
-				if slinfo.system == False:self.model.append(['<span size="9000">%s</span>' % s, img, slinfo])				
-
-
+				slinfo = utils.ScreenletInfo(s, '','', '','', '', img)
+			#Append screenlet info into global dictionary used later to filter screenlets
+			self.loaded_screenlets[slinfo.name] = slinfo
+			self.model.append(['<span size="9000">%s</span>' % s, img, slinfo])	
 	
 	def get_Info_by_name (self, name):
 		"""Returns a ScreenletInfo-object for the screenlet with given name."""
-		for row in self.model:
+		for row in self.model_filter:
 			if row[2] and row[2].name == name:
 				return row[2]
 		return None
@@ -248,17 +238,17 @@ class ScreenletsManager(object):
 		int the IconView."""
 		sel = self.view.get_selected_items()
 		if sel and len(sel)>0 and len(sel[0])>0:
-			it = self.model.get_iter(sel[0][0])
+			it = self.model_filter.get_iter(sel[0][0])
 			if it:
-				return self.model.get_value(it, 2)
+				return self.model_filter.get_value(it, 2)
 		return None
 	
 	def reset_selected_screenlet(self):
 		sel = self.view.get_selected_items()
 		if sel and len(sel) > 0 and len(sel[0]) > 0:
-			it = self.model.get_iter(sel[0][0])
+			it = self.model_filter.get_iter(sel[0][0])
 			if it:
-				info = self.model.get_value(it, 2)
+				info = self.model_filter.get_value(it, 2)
 				if screenlets.show_question(None, _('Do you really want to reset the %sScreenlet configuration?') % info.name, _('Reset Screenlet')):
 					# delete screenlet's config directory 
 					os.system('rm -rf %s/%s' % (screenlets.DIR_CONFIG, info.name))
@@ -272,7 +262,7 @@ class ScreenletsManager(object):
 	
 	def set_screenlet_active (self, name, active):
 		"""Set the screenlet's active-state to active (True/False)."""
-		for row in self.model:
+		for row in self.model_filter:
 			if row[2].name == name[:-9]:
 				row[2].active = active
 				# if selected, also toggle checkbox
@@ -280,7 +270,67 @@ class ScreenletsManager(object):
 				if sel and sel.name == name[:-9]:
 					self.recreate_infobox(sel)
 				break
-	
+	def visible_cb(self, model, iter, data):
+        	slinfo = model.get_value(iter,2)
+		if(slinfo != None):
+			#Check if filter box value matches screenlet name
+			if self.filter_input != '':
+				filter_slname = str(slinfo.name).lower()
+				filter_find = filter_slname.find(self.filter_input)
+				if filter_find == -1:
+					return False
+			
+			wshow = True
+			#Check if screenlet is currently running
+			if self.combo_type_sel == 1: 
+				if self.loaded_screenlets[slinfo.name].active == False:
+					return False
+			elif self.combo_type_sel == 2:
+				if slinfo.autostart != True:	
+					return False
+			elif self.combo_type_sel == 3:
+				if slinfo.system != True:
+					return False
+			elif self.combo_type_sel == 4:
+				if slinfo.system != False:
+					return False
+			#Check if category selection matches screenlet category
+			if self.available_categories[self.combo_cat_sel]==CATEGORIES_ALL:
+				wshow = True
+			elif self.available_categories[self.combo_cat_sel]==slinfo.category:
+				wshow = True
+			elif (not(slinfo.category in self.available_categories)) and self.available_categories[self.combo_cat_sel]==CATEGORIES_MISC:
+				wshow = True
+			else:
+				wshow = False
+			return wshow
+
+
+
+
+		else:
+			return False
+
+
+
+	def refilter_screenlets(self,widget,id):
+		if id == 'search_clean':
+			self.txtsearch.set_text('')
+			self.filter_input = ''
+		elif id == 'search_changed':
+			self.filter_input = str(self.txtsearch.get_text()).lower()
+		elif id == 'type_changed':
+			self.combo_type_sel = self.combo.get_active()
+			if(self.combo_type_sel == 1):
+				lst_r = utils.list_running_screenlets()
+				if lst_r != None:
+					for item in lst_r:
+						if item[:-9] in self.loaded_screenlets.keys():
+							self.loaded_screenlets[item[:-9]].active=True
+						
+		elif id == 'category_changed':
+			self.combo_cat_sel = self.combo1.get_active()
+		self.model_filter.refilter()
 	# ui creation
 	
 	def create_ui (self):
@@ -311,10 +361,11 @@ class ScreenletsManager(object):
 		vbox.pack_start(hbox, True, True)
 		hbox.show()
 		# iconview
-		self.model= gtk.ListStore(object)
 		self.view = iv = gtk.IconView()
 		self.model = gtk.ListStore(str, gtk.gdk.Pixbuf, object)
-		iv.set_model(self.model)
+		self.model_filter = self.model.filter_new()
+		self.model_filter.set_visible_func(self.visible_cb, None)
+		iv.set_model(self.model_filter)
 		iv.set_markup_column(0)
 		iv.set_pixbuf_column(1)
 		# disable UI for root user
@@ -331,7 +382,7 @@ class ScreenletsManager(object):
 		iv.connect("drag_data_received", self.drag_data_received)
 		# wrap iconview in scrollwin
 		sw = self.slwindow = gtk.ScrolledWindow()
-		sw.set_size_request(560, 350)
+		sw.set_size_request(560, 380)
 		sw.set_shadow_type(gtk.SHADOW_IN)
 		sw.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
 		sw.add(iv)
@@ -410,7 +461,7 @@ class ScreenletsManager(object):
 		but8.set_alignment(0,0.5)
 		but9.set_alignment(0,0.5)
 		but1.set_tooltip_text(_("Launch/add a new instance of the selected Screenlet ..."))
-		but2.set_tooltip_text(_("Install a new Screenlet, SuperKaramba or Web Widget or Web Application  ..."))
+		but2.set_tooltip_text(_("Install a new Screenlet or SuperKaramba  ..."))
 		but3.set_tooltip_text(_("Permanently uninstall/delete the currently selected Screenlet ..."))
 		but4.set_tooltip_text(_("Reset this Screenlet configuration (will only work if Screenlet isn't running)"))
 		but5.set_tooltip_text(_("Install new theme for this screenlet"))
@@ -423,27 +474,39 @@ class ScreenletsManager(object):
 		self.label.set_width_chars(70)
 		self.label.set_alignment(0, 0)
 		self.label.set_size_request(-1, 65)
+		self.filter_input=''
     		self.btnsearch = gtk.Button()
+		self.filterbox = gtk.VBox()
     		self.searchbox = gtk.HBox()
     		self.txtsearch = gtk.Entry()
 		self.btnsearch.set_image(gtk.image_new_from_stock(gtk.STOCK_CLOSE, 
 			gtk.ICON_SIZE_BUTTON))
-    		self.btnsearch.connect("clicked",self.redraw_screenlets, 'clean')
-    		self.txtsearch.connect("changed",self.redraw_screenlets, 'enter')
-    		self.txtsearch.connect("backspace",self.redraw_screenlets, 'backspace')
+    		self.btnsearch.connect("clicked",self.refilter_screenlets, 'search_clean')
+    		self.txtsearch.connect("changed",self.refilter_screenlets, 'search_changed')
+    		
 
     		self.searchbox.pack_start(self.txtsearch, 1)
     		self.searchbox.pack_start(self.btnsearch, False)
-		butbox.pack_start(self.searchbox, False,0,3)
+		self.filterbox.pack_start(self.searchbox, False)
+
 		self.combo = gtk.combo_box_new_text()
 		self.combo.append_text(_('All Screenlets'))
 		self.combo.append_text(_('Running Screenlets'))
 		self.combo.append_text(_('Autostart Screenlets'))
 		self.combo.append_text(_('Only native Screenlets'))
 		self.combo.append_text(_('Only third party'))
+		self.combo_type_sel=0
 		self.combo.set_active(0)
-    		self.combo.connect("changed",self.redraw_screenlets, 'enter')
+    		self.combo.connect("changed",self.refilter_screenlets, 'type_changed')
 		self.combo.show()
+		self.combo1 = gtk.combo_box_new_text()
+		self.combo_cat_sel=0
+		self.combo1.set_active(0)
+		self.combo1.connect("changed",self.refilter_screenlets, 'category_changed')
+		self.combo1.show()
+		self.filterbox.pack_start(self.combo1, False)
+		self.filterbox.pack_start(self.combo, False)
+		butbox.pack_start(self.filterbox, False,0,3)
 		butbox.pack_start(but1, False)
 		butbox.pack_start(but2, False)
 		butbox.pack_start(but3, False)
@@ -455,7 +518,6 @@ class ScreenletsManager(object):
 		#sep2 =   gtk.HSeparator()
 		#butbox.pack_start(sep2, False,False,5)
 		butbox.pack_start(but8, False)
-		butbox.pack_start(self.combo, False)
 		#butbox.pack_start(self.label, False)
 		butbox.show_all()
 		hbox.pack_start(butbox, False, False, 10)
@@ -575,10 +637,7 @@ class ScreenletsManager(object):
 		self.bbox.pack_start(ibox, False,False)
 
 	def redraw_screenlets(self,widget,id):
-		if id == 'backspace':
-			if len(self.txtsearch.get_text()) == 1:
-				self.txtsearch.set_text('')
-		elif id == 'clean':
+		if id == 'clean':
 			self.txtsearch.set_text('')
 		else:
 			self.model.clear()
@@ -895,6 +954,7 @@ class ScreenletsManager(object):
 					os.system('sh '+ DIR_AUTOSTART + s + ' &')	
 		elif id == 'closeall':
 			utils.quit_all_screenlets()
+			self.refilter_screenlets(None,'type_changed')
 
 		elif id == 'download':
 			if screenlets.UBUNTU:
@@ -914,12 +974,6 @@ class ScreenletsManager(object):
 		button = gtk.RadioButton(button, _('Install SuperKaramba Theme'))
 		install_rbs.pack_start(button, True, True, 0)
 		button.show()
-		button = gtk.RadioButton(button, _('Convert Web Widget'))
-		install_rbs.pack_start(button, True, True, 0)
-		button.show()
-		button = gtk.RadioButton(button, _('Install Web Application'))
-		install_rbs.pack_start(button, True, True, 0)
-		button.show()
 
 		dialog = gtk.Dialog(_("Install"),self.window,
                     gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT,
@@ -935,10 +989,6 @@ class ScreenletsManager(object):
 			active_label = active_radios[0].get_label()
 			if active_label in (_('Install Screenlet'), _('Install SuperKaramba Theme')):
 				self.show_install_dialog()
-			elif active_label == _('Convert Web Widget'):
-				self.show_widget_converter()
-			elif active_label == _('Install Web Application'):
-				self.show_webapp()						
 		dialog.destroy()
 
 	def show_options_ui(self):
@@ -1018,160 +1068,6 @@ class ScreenletsManager(object):
 			f.close()
 		dialog.destroy()
 
-	def show_webapp(self):
-		label1 = gtk.Label(_('Web Application Url'))
-		label2 = gtk.Label(_('Web Application Name'))
-		code = gtk.Entry()
-		name = gtk.Entry()
-		h = gtk.HBox()
-		h1 = gtk.HBox()	
-		h.pack_start(label1,False,False)
-		h.pack_start(code,True,True)
-		h1.pack_start(label2,False,False)
-		h1.pack_start(name,True,True)
-      		dialog = gtk.Dialog(_("Install Web Application"),self.window,
-                     gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT,
-                     (gtk.STOCK_CANCEL, gtk.RESPONSE_REJECT,
-                      gtk.STOCK_OK, gtk.RESPONSE_ACCEPT))
-    		label1.show()
-    		label2.show()
-		code.show()
-		name.show()
-		h.show()
-		h1.show()
-		dialog.vbox.pack_start(h,False,False,5)
-		dialog.vbox.pack_start(h1,False,False,5)
-				
-			
-		resp = dialog.run()
-		ret = None
-		if resp == gtk.RESPONSE_ACCEPT:
-			if code.get_text() != '':
-				if name.get_text() != '':
-					try:
-						a = name.get_text()
-						a = a.replace(' ','')
-						if os.path.isdir(DIR_USER + '/' + a):#found_path != None:
-							if screenlets.show_question(None,(_("There is already a screenlet with that name installed\nDo you wish to continue?") )):
-								pass
-							else: 
-								return False
-						os.system('mkdir -p ' +DIR_USER + '/' + a + '/themes/default')
-						os.system('mkdir -p ' +DIR_USER + '/' + a + '/mozilla') # probably not needed since webkit
-						# this is just to install something if basic pack is not installed
-						os.system('cp ' + screenlets.INSTALL_PREFIX + '/share/screenlets-manager/WebframeScreenlet.py ' +DIR_USER + '/' + a + '/' + a + 'Screenlet.py')
-						os.system('cp ' + screenlets.INSTALL_PREFIX + '/share/screenlets-manager/webframe.png ' +DIR_USER + '/' + a + '/icon.png')				
-						os.system('cp ' + screenlets.INSTALL_PREFIX + '/share/screenlets-manager/prefs.js ' +DIR_USER + '/' + a + '/mozilla')				
-						os.system('cp ' + screenlets.INSTALL_PREFIX + '/share/screenlets-manager/webframe.png ' +DIR_USER + '/' + a + '/themes/default')
-						# install the one from basic pack (probably fullest and most updated)
-						os.system('cp ' + screenlets.INSTALL_PREFIX + '/share/screenlets/screenlets-pack-basic/Webframe/WebframeScreenlet.py ' +DIR_USER + '/' + a + '/' + a + 'Screenlet.py')
-						os.system('cp ' + screenlets.INSTALL_PREFIX + '/share/screenlets/screenlets-pack-basic/Webframe/icon* ' +DIR_USER + '/' + a)
-						os.system('cp ' + screenlets.INSTALL_PREFIX + '/share/screenlets/screenlets-pack-basic/Webframe/*.txt ' +DIR_USER + '/' + a)
-						os.system('cp -r ' + screenlets.INSTALL_PREFIX + '/share/screenlets/screenlets-pack-basic/Webframe/mo ' +DIR_USER + '/' + a)
-						os.system('cd ' + DIR_USER + '/' + a + '/mo && find -name *.mo | rename -v "s/webframe/' + a.lower() +'/"')
-						os.system('cp -r ' + screenlets.INSTALL_PREFIX + '/share/screenlets/screenlets-pack-basic/Webframe/themes ' +DIR_USER + '/' + a)
-						os.system('cp -r ' + screenlets.INSTALL_PREFIX + '/share/screenlets/screenlets-pack-basic/Webframe/mozilla ' +DIR_USER + '/' + a)
-		
-						enginecopy = open(DIR_USER + '/' + a + '/' + a + 'Screenlet.py','r')
-						enginesave = enginecopy.read()
-						enginesave = enginesave.replace('WebframeScreenlet',a + 'Screenlet')
-						enginesave = enginesave.replace("home_uri = ''","home_uri = " + chr(34) + code.get_text() + chr(34))
-						enginecopy.close()
-						enginecopy = open(DIR_USER + '/' + a + '/' + a + 'Screenlet.py','w')
-						enginecopy.write(enginesave)
-						enginecopy.close()
-						screenlets.show_message (None,_("Web Application was successfully installed"))
-						self.model.clear()
-						self.load_screenlets()			
-					except:	screenlets.show_error(None,_("Error installing!!!"))
-				else:	screenlets.show_error(None,_("Please specify a name for the widget"))
-			else:	screenlets.show_error(None,_("No HTML code found"))
-		dialog.destroy()
-
-	def show_widget_converter(self):
-		label1 = gtk.Label(_('Convert any webpage widget into a Screenlet.'))
-		label2 = gtk.Label(_('Step 1 : Find the widget you want to convert'))
-		label3 = gtk.Label(_('Step 2 : Copy and Paste the HTML from the widget in the box below'))
-		label4 = gtk.Label(_('Step 3 : Give it a name in the box below and click on Ok to convert'))
-		label5 = gtk.Label(_('The name of the widget'))
-		code = gtk.Entry()
-		name = gtk.Entry()
-		h = gtk.HBox()
-		h1 = gtk.HBox()
-		self.combo1 = combo = gtk.combo_box_new_text()
-		combo.append_text('Google Gadgets')
-		combo.append_text('Yourminis Widgets')
-		combo.append_text('SpringWidgets')
-		combo.append_text('Widgetbox')
-		combo.set_active(0)
-		web = gtk.Button('Go to web page')
-		web.connect('clicked', self.button_clicked, 'widgetsite')
-    		label1.show()
-    		label2.show()
-    		label3.show()
-    		label4.show()
-    		label5.show()
-		combo.show()
-		name.show()
-		web.show()
-		h.show()
-		h1.show()
-		code.show()
-		dialog = gtk.Dialog(_("Widget converter"),
-                    self.window,
-                    gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT,
-                    (gtk.STOCK_CANCEL, gtk.RESPONSE_REJECT,
-                     gtk.STOCK_OK, gtk.RESPONSE_ACCEPT))
-		#dialog.set_size_request(300, 500)
-		dialog.vbox.pack_start(label1,False,False,20)
-		dialog.vbox.pack_start(label2,True,False,5)
-		h.pack_start(combo,True,True,5)
-		h.pack_start(web,False,False,5)
-		dialog.vbox.pack_start(h,False,False,5)
-		dialog.vbox.pack_start(label3,False,False,10)
-		dialog.vbox.pack_start(code,False,False,5)
-		dialog.vbox.pack_start(label4,False,False,5)
-		h1.pack_start(label5,False,False,5)			
-		h1.pack_start(name,True,True,5)
-		dialog.vbox.pack_start(h1,False,False,5)
-		resp = dialog.run()
-		ret = None
-		if resp == gtk.RESPONSE_ACCEPT:
-			if code.get_text() != '':
-				if name.get_text() != '':
-					try:
-						a = name.get_text()
-						a = a.replace(' ','')
-						if os.path.isdir(DIR_USER + '/' + a):#found_path != None:
-							if screenlets.show_question(None,(_("There is already a screenlet with that name installed\nDo you wish to continue?") )):
-								pass
-							else: 
-								return False
-						os.system('mkdir ' +DIR_USER + '/' + a)
-						os.system('mkdir ' +DIR_USER + '/' + a + '/themes')
-						os.system('mkdir ' +DIR_USER + '/' + a + '/themes/default')
-						os.system('mkdir ' +DIR_USER + '/' + a + '/mozilla')
-						f = open(DIR_USER + '/' + a  + '/' + 'index.html' , 'w')
-						f.write(code.get_text())
-						f.close()
-						os.system('cp ' + screenlets.INSTALL_PREFIX + '/share/screenlets-manager/WidgetScreenlet.py ' +DIR_USER + '/' + a + '/' + a + 'Screenlet.py')
-						os.system('cp ' + screenlets.INSTALL_PREFIX + '/share/screenlets-manager/widget.png ' +DIR_USER + '/' + a + '/icon.png')				
-						os.system('cp ' + screenlets.INSTALL_PREFIX + '/share/screenlets-manager/widget.png ' +DIR_USER + '/' + a + '/themes/default')
-						enginecopy = open(DIR_USER + '/' + a + '/' + a + 'Screenlet.py','r')
-						enginesave = enginecopy.read()
-						enginesave = enginesave.replace('WidgetScreenlet',a + 'Screenlet')
-						enginecopy.close()
-						enginecopy = open(DIR_USER + '/' + a + '/' + a + 'Screenlet.py','w')
-						enginecopy.write(enginesave)
-						enginecopy.close()
-						screenlets.show_message (None,_("Widget was successfully converted"))
-						self.model.clear()
-						self.load_screenlets()			
-					except:	screenlets.show_error(None,_("Error converting!!!"))
-				else:	screenlets.show_error(None,_("Please specify a name for the widget"))		
-			else:	screenlets.show_error(None,_("No HTML code found"))			
-		dialog.destroy()
-
 	def handle_screenlet_registered (self, name):
 		"""Callback for dbus-signal, called when a new screenlet gets 
 		registered within the daemon."""
@@ -1257,6 +1153,7 @@ class ScreenletsManager(object):
 					widget.set_sensitive(False)
 			else:
 				utils.delete_autostarter(info.name)
+				self.refilter_screenlets(None,'None')
 
 	def toggle_tray (self, widget):
 		"""Callback for handling changes to the tray-CheckButton."""
